@@ -4,7 +4,7 @@ from mindee.fields.amount import Amount
 def test_constructor():
     field_dict = {
         "amount": "2",
-        "probability": 0.1,
+        "confidence": 0.1,
         "segmentation": {
             "bounding_box": [
                 [0.016, 0.707],
@@ -20,6 +20,6 @@ def test_constructor():
 
 
 def test_constructor_no_amount():
-    field_dict = {"amount": "N/A", "probability": 0.1}
+    field_dict = {"amount": "N/A", "confidence": 0.1}
     amount = Amount(field_dict)
     assert amount.value is None
